=== added directory 'plugin/errmsg_notify'
=== added file 'plugin/errmsg_notify/errmsg_notify.cc'
--- plugin/errmsg_notify/errmsg_notify.cc	1970-01-01 00:00:00 +0000
+++ plugin/errmsg_notify/errmsg_notify.cc	2010-01-20 08:20:59 +0000
@@ -0,0 +1,117 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Monty Taylor
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <cstdio>  /* for vsnprintf */
+#include <stdarg.h>  /* for va_list */
+#include <unistd.h>  /* for write(2) */
+#include <libnotifymm.h>
+
+#include <string>
+#include <vector>
+
+#include <drizzled/plugin/error_message.h>
+#include <drizzled/gettext.h>
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/registry.h>
+
+
+/* todo, make this dynamic as needed */
+#define MAX_MSG_LEN 8192
+
+using namespace drizzled;
+using namespace std;
+
+
+class Error_message_notify : public plugin::ErrorMessage
+{
+  vector<string> errmsg_tags;
+public:
+  Error_message_notify()
+   : plugin::ErrorMessage("Error_message_notify"),
+     errmsg_tags(5)
+  {
+    errmsg_tags.push_back("Unknown");
+    errmsg_tags.push_back("Debug");
+    errmsg_tags.push_back("Info");
+    errmsg_tags.push_back("Warn");
+    errmsg_tags.push_back("Error");
+  }
+
+  virtual bool errmsg(Session *, int priority, const char *format, va_list ap)
+  {
+    char msgbuf[MAX_MSG_LEN];
+    int prv;
+
+    prv= vsnprintf(msgbuf, MAX_MSG_LEN, format, ap);
+    if (prv < 0) return true;
+
+    Notify::Notification n(errmsg_tags[priority], msgbuf);
+    /**
+     * @TODO: Make this timeout a system variable
+     */
+    n.set_timeout(3000);
+    
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+    try
+    {
+      if (!n.show())
+#else
+      auto_ptr<Glib::Error> error;
+      if (!n.show(error))
+#endif
+      {
+        fprintf(stderr, "Failed to send error message to libnotify\n");
+        return true;
+      }
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+     }
+     catch (Glib::Error& err)
+     {
+        fprintf(stderr, err.what().c_str());
+     }
+#endif
+
+    return false;
+  }
+};
+
+static Error_message_notify *handler= NULL;
+static int plugin_init(plugin::Registry &registry)
+{
+  Notify::init("Drizzled");
+  handler= new Error_message_notify();
+  registry.add(handler);
+
+  return 0;
+}
+
+static int plugin_deinit(plugin::Registry &registry)
+{
+
+  if (handler)
+  {
+    registry.remove(handler);
+    delete handler;
+  }
+  return 0;
+}
+
+DRIZZLE_PLUGIN(plugin_init, plugin_deinit, NULL, NULL);

=== added file 'plugin/errmsg_notify/plugin.ac'
--- plugin/errmsg_notify/plugin.ac	1970-01-01 00:00:00 +0000
+++ plugin/errmsg_notify/plugin.ac	2010-01-20 08:20:59 +0000
@@ -0,0 +1,11 @@
+PKG_CHECK_MODULES([gtkmm], [gtkmm-2.4], [
+  ac_cv_have_gtkmm=yes
+],[
+  ac_cv_have_gtkmm=no
+])
+PKG_CHECK_MODULES([libnotifymm], [libnotifymm-1.0], [
+  ac_cv_have_libnotifymm=yes
+],[
+  ac_cv_have_libnotifymm=no
+])
+

=== added file 'plugin/errmsg_notify/plugin.ini'
--- plugin/errmsg_notify/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/errmsg_notify/plugin.ini	2010-01-20 08:20:59 +0000
@@ -0,0 +1,11 @@
+[plugin]
+title=libnotify Error Message Plugin
+description=Errmsg Plugin that sends messages to libnotify.
+title=errmsg_notify
+version=1.0
+author=Monty Taylor
+license=PLUGIN_LICENSE_GPL
+sources=errmsg_notify.cc
+cxxflags=${NO_WERROR} ${libnotifymm_CFLAGS} ${gtkmm_CFLAGS}
+ldflags=${libnotifymm_LDFLAGS} ${gtkmm_LDFLAGS}
+build_conditional="${ac_cv_have_libnotifymm}" = "yes" -a "${ac_cv_have_gtkmm}" = "yes"

